@@ -1,4 +1,4 @@
-## ---- echo = FALSE, message = FALSE-------------------------------------------
+## ----echo = FALSE, message = FALSE--------------------------------------------
 knitr::opts_chunk$set(comment = "")
 library(V8)
 
@@ -18,13 +18,9 @@ cat(ct$eval("JSON.stringify({x:Math.random()})"))
 # Simple closure
 ct$eval("(function(x){return x+1;})(123)")
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  ct$source(system.file("js/underscore.js", package="V8"))
-#  ct$source("https://cdnjs.cloudflare.com/ajax/libs/crossfilter/1.3.11/crossfilter.min.js")
-
-## ----echo=FALSE, results='hide'-----------------------------------------------
-ct$source(system.file("js/underscore.js", package="V8"))
-ct$source(system.file("js/crossfilter.js", package="V8"))
+## -----------------------------------------------------------------------------
+ct$source('https://cdnjs.cloudflare.com/ajax/libs/underscore.js/1.13.6/underscore-min.js')
+ct$source("https://cdnjs.cloudflare.com/ajax/libs/crossfilter/1.3.11/crossfilter.min.js")
 
 ## -----------------------------------------------------------------------------
 ct$assign("mydata", mtcars)
@@ -38,27 +34,47 @@ ct$get("bar")
 ## -----------------------------------------------------------------------------
 ct$call("_.filter", mtcars, JS("function(x){return x.mpg < 15}"))
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----error=TRUE---------------------------------------------------------------
+js = 'function test_number(x){
+  var promise = new Promise(function(resolve, reject) {
+    if(x == 42)
+      resolve(true)
+    else
+      reject("This is wrong")
+  })
+  return promise;
+}'
+
+# Call will just show a promise
+ctx <- V8::v8()
+ctx$eval(js)
+
+# A promise does not return anything in itself:
+ctx$call("test_number", 42)
+
+# Resolve the promise to the result
+ctx$call("test_number", 42, await = TRUE)
+
+# A rejected promise will throw an error
+ctx$call("test_number", 41, await = TRUE)
+
+## ----eval=FALSE---------------------------------------------------------------
 #  # Load some data
 #  data(diamonds, package = "ggplot2")
 #  ct$assign("diamonds", diamonds)
 #  ct$console()
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  output <- ct$get("output")
 #  print(output)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ct <- v8()
 #  ct$source("https://cdnjs.cloudflare.com/ajax/libs/crossfilter/1.3.11/crossfilter.min.js")
 #  ct$eval('var cf = crossfilter || console.error("failed to load crossfilter!")')
 
 ## -----------------------------------------------------------------------------
-ct <- v8(typed_arrays = FALSE);
-ct$get(JS("Object.keys(global)"))
-
-## -----------------------------------------------------------------------------
-ct <- v8(typed_arrays = TRUE);
+ct <- v8();
 ct$get(JS("Object.keys(global)"))
 
 ## -----------------------------------------------------------------------------
@@ -86,7 +102,7 @@ ct$validate("function(x){2*x}")
 ct$validate("(function(x){2*x})")
 ct$validate("!function(x){2*x}")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ctx <- v8()
 #  ctx$console()
 
